@@ -330,7 +330,7 @@ static void ssl_ext_mp_init(server_rec *s, pool *p)
                     cpVHostID, sk_X509_INFO_num(sk));
             if (sk_X509_INFO_num(sk) > 0) {
                 SSL_CTX_set_client_cert_cb(ctx, ssl_ext_mp_clientcert_cb);
-                ap_ctx_set(sc->ctx, "ssl::proxy::clientcerts", (void *)sk);
+                sc->skProxyClientCerts = sk;
             }
         }
 
@@ -592,7 +592,7 @@ static int ssl_ext_mp_clientcert_cb(SSL *ssl, X509 **x509, EVP_PKEY **pkey)
     servername = ap_ctx_get(pCtx, "ssl::proxy::servername");
 
     sc         = mySrvConfig(s);
-    pcerts     = ap_ctx_get(sc->ctx, "ssl::proxy::clientcerts");
+    pcerts     = sc->skProxyClientCerts;
 
     ssl_log(s, SSL_LOG_DEBUG, "Proxy client certificate callback: (%s) entered");
 
