@@ -123,7 +123,6 @@ void ssl_init_Module(server_rec *s, pool *p)
     SSLSrvConfigRec *sc;
     server_rec *s2;
     char *cp;
-    int n;
 
     mc->nInitCount++;
 
@@ -269,8 +268,7 @@ void ssl_init_Module(server_rec *s, pool *p)
     /*
      * Seed the Pseudo Random Number Generator (PRNG)
      */
-    n = ssl_rand_seed(s, p, SSL_RSCTX_STARTUP);
-    ssl_log(s, SSL_LOG_INFO, "Init: Seeding PRNG with %d bytes of entropy", n);
+    ssl_rand_seed(s, p, SSL_RSCTX_STARTUP, "Init: ");
 
     /*
      *  allocate the temporary RSA keys and DH params
@@ -342,14 +340,12 @@ void ssl_init_TmpKeysHandle(int action, server_rec *s, pool *p)
     unsigned char *ucp;
     RSA *rsa;
     DH *dh;
-    int n;
 
     /* Generate Keys and Params */
     if (action == SSL_TKP_GEN) {
 
         /* seed PRNG */
-        n = ssl_rand_seed(s, p, SSL_RSCTX_STARTUP);
-        ssl_log(s, SSL_LOG_INFO, "Init: Seeding PRNG with %d bytes of entropy", n);
+        ssl_rand_seed(s, p, SSL_RSCTX_STARTUP, "Init: ");
 
         /* generate 512 bit RSA key */
         ssl_log(s, SSL_LOG_INFO, "Init: Generating temporary RSA private keys (512/1024 bits)");
